/**
 * Edits a guild's welcome screen.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to edit the welcome screen of.
 * @param options - The parameters for the edit of the welcome screen.
 * @returns An instance of the edited {@link WelcomeScreen}.
 *
 * @remarks
 * Requires the `MANAGE_GUILD` permission.
 *
 * Fires a _Guild Update_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#modify-guild-welcome-screen}
 */
export async function editWelcomeScreen(bot, guildId, options) {
    const result = await bot.rest.runMethod(bot.rest, "PATCH", bot.constants.routes.GUILD_WELCOME_SCREEN(guildId), {
        enabled: options.enabled,
        welcome_screen: options.welcomeScreen?.map((welcomeScreen) => ({
            channel_id: welcomeScreen.channelId,
            description: welcomeScreen.description,
            emoji_id: welcomeScreen.emojiId,
            emoji_name: welcomeScreen.emojiName,
        })),
        description: options.description,
    });
    return bot.transformers.welcomeScreen(bot, result);
}
