import { Collection } from "../../util/collection.js";
/**
 * Gets the list of bans for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the list of bans for.
 * @param options - The parameters for the fetching of the list of bans.
 * @returns A collection of {@link Ban} objects assorted by user ID.
 *
 * @remarks
 * Requires the `BAN_MEMBERS` permission.
 *
 * Users are ordered by their IDs in _ascending_ order.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#get-guild-bans}
 */
export async function getBans(bot, guildId, options) {
    const results = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.GUILD_BANS(guildId, options));
    return new Collection(results.map((result) => {
        const user = bot.transformers.user(bot, result.user);
        return [
            user.id,
            {
                reason: result.reason ?? undefined,
                user: user,
            },
        ];
    }));
}
