"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getChannelWebhooks = void 0;
const collection_js_1 = require("../../util/collection.js");
/**
 * Gets a list of webhooks for a channel.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel which to get the webhooks of.
 * @returns A collection of {@link Webhook} objects assorted by webhook ID.
 *
 * @remarks
 * Requires the `MANAGE_WEBHOOKS` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/webhook#get-channel-webhooks}
 */
async function getChannelWebhooks(bot, channelId) {
    const results = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.CHANNEL_WEBHOOKS(channelId));
    return new collection_js_1.Collection(results.map((result) => {
        const webhook = bot.transformers.webhook(bot, result);
        return [webhook.id, webhook];
    }));
}
exports.getChannelWebhooks = getChannelWebhooks;
