"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createStageInstance = void 0;
/**
 * Creates a stage instance associated with a stage channel.
 *
 * @param bot - The bot instance to use to make the request.
 * @param options - The parameters for the creation of the stage instance.
 * @returns An instance of the created {@link StageInstance}.
 *
 * @remarks
 * Requires the user to be a moderator of the stage channel.
 *
 * Fires a _Stage Instance Create_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/stage-instance#create-stage-instance}
 */
async function createStageInstance(bot, options) {
    const result = await bot.rest.runMethod(bot.rest, "POST", bot.constants.routes.STAGE_INSTANCES(), {
        channel_id: options.channelId.toString(),
        topic: options.topic,
        send_start_notification: options.sendStartNotification,
        reason: options.reason,
    });
    return bot.transformers.stageInstance(bot, result);
}
exports.createStageInstance = createStageInstance;
