"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getActiveThreads = void 0;
const collection_js_1 = require("../../../util/collection.js");
/**
 * Gets the list of all active threads for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the threads of.
 * @returns An instance of {@link ActiveThreads}.
 *
 * @remarks
 * Returns both public and private threads.
 *
 * Threads are ordered by the `id` property in descending order.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#list-active-guild-threads}
 */
async function getActiveThreads(bot, guildId) {
    const results = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.THREAD_ACTIVE(guildId));
    return {
        threads: new collection_js_1.Collection(results.threads.map((result) => {
            const thread = bot.transformers.channel(bot, { channel: result });
            return [thread.id, thread];
        })),
        members: new collection_js_1.Collection(results.members.map((result) => {
            const member = bot.transformers.threadMember(bot, result);
            return [member.id, member];
        })),
    };
}
exports.getActiveThreads = getActiveThreads;
