"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeThreadMember = void 0;
/**
 * Removes a member from a thread.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the thread to remove the thread member of.
 * @param userId - The user ID of the thread member to remove.
 *
 * @remarks
 * If the thread is of type {@link ChannelTypes.GuildPrivateThread}, requires to be the creator of the thread.
 * Otherwise, requires the `MANAGE_THREADS` permission.
 *
 * Requires the thread not be archived.
 *
 * Fires a _Thread Members Update_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#remove-thread-member}
 */
async function removeThreadMember(bot, channelId, userId) {
    return await bot.rest.runMethod(bot.rest, "DELETE", bot.constants.routes.THREAD_USER(channelId, userId));
}
exports.removeThreadMember = removeThreadMember;
