"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getScheduledEvents = void 0;
const collection_js_1 = require("../../../util/collection.js");
/**
 * Gets the list of scheduled events for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the scheduled events from.
 * @param options - The parameters for the fetching of the scheduled events.
 * @returns A collection of {@link ScheduledEvent} objects assorted by event ID.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild-scheduled-event#list-scheduled-events-for-guild}
 */
async function getScheduledEvents(bot, guildId, options) {
    const results = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.GUILD_SCHEDULED_EVENTS(guildId, options?.withUserCount));
    return new collection_js_1.Collection(results.map((result) => {
        const event = bot.transformers.scheduledEvent(bot, result);
        return [event.id, event];
    }));
}
exports.getScheduledEvents = getScheduledEvents;
