"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGuildPreview = void 0;
// TODO: Move `GuildPreview` into its own transformer file.
/**
 * Gets the preview of a guild by a guild's ID.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the preview of.
 * @returns An instance of {@link GuildPreview}.
 *
 * @remarks
 * If the bot user is not in the guild, the guild must be lurkable.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#get-guild-preview}
 */
async function getGuildPreview(bot, guildId) {
    const result = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.GUILD_PREVIEW(guildId));
    return {
        id: bot.transformers.snowflake(result.id),
        name: result.name,
        icon: result.icon ?? undefined,
        splash: result.splash ?? undefined,
        discoverySplash: result.discovery_splash ?? undefined,
        emojis: result.emojis.map((emoji) => bot.transformers.emoji(bot, emoji)),
        features: result.features,
        approximateMemberCount: result.approximate_member_count,
        approximatePresenceCount: result.approximate_presence_count,
        description: result.description ?? undefined,
        stickers: result.stickers.map((sticker) => bot.transformers.sticker(bot, sticker)),
    };
}
exports.getGuildPreview = getGuildPreview;
