"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGuildSplashURL = void 0;
/**
 * Builds the URL to a guild splash stored in the Discord CDN.
 *
 * @param bot - The bot instance to use to build the URL.
 * @param guildId - The ID of the guild to get the splash of.
 * @param imageHash - The hash identifying the splash image.
 * @param options - The parameters for the building of the URL.
 * @returns The link to the resource or `undefined` if the guild does not have a splash image set.
 */
function getGuildSplashURL(bot, guildId, imageHash, options) {
    return imageHash
        ? bot.utils.formatImageURL(bot.constants.routes.GUILD_SPLASH(guildId, typeof imageHash === "string" ? imageHash : bot.utils.iconBigintToHash(imageHash)), options?.size || 128, options?.format)
        : undefined;
}
exports.getGuildSplashURL = getGuildSplashURL;
