"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPruneCount = void 0;
/**
 * Gets the number of members that would be kicked from a guild during pruning.
 *
 * @param bot - The bot instance used to make the request
 * @param guildId - The ID of the guild to get the prune count of.
 * @param options - The parameters for the fetching of the prune count.
 * @returns A number indicating the number of members that would be kicked.
 *
 * @remarks
 * Requires the `KICK_MEMBERS` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#get-guild-prune-count}
 */
async function getPruneCount(bot, guildId, options) {
    if (options?.days && options.days < 1)
        throw new Error(bot.constants.Errors.PRUNE_MIN_DAYS);
    if (options?.days && options.days > 30)
        throw new Error(bot.constants.Errors.PRUNE_MAX_DAYS);
    const result = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.GUILD_PRUNE(guildId));
    return result.pruned;
}
exports.getPruneCount = getPruneCount;
