"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.upsertGlobalApplicationCommands = void 0;
const collection_js_1 = require("../../../util/collection.js");
/**
 * Re-registers the list of global application commands, overwriting the previous commands completely.
 *
 * @param bot - The bot instance to use to make the request.
 * @param commands - The list of commands to use to overwrite the previous list.
 * @returns A collection of {@link ApplicationCommand} objects assorted by command ID.
 *
 * @remarks
 * ❗ Commands that are not present in the `commands` array will be __deleted__.
 *
 * ⚠️ Commands that do not already exist will count towards the daily limit of _200_ new commands.
 *
 * @see {@link https://discord.com/developers/docs/interactions/application-commands#bulk-overwrite-global-application-commands}
 */
async function upsertGlobalApplicationCommands(bot, commands) {
    const results = await bot.rest.runMethod(bot.rest, "PUT", bot.constants.routes.COMMANDS(bot.applicationId), commands.map((command) => bot.transformers.reverse.createApplicationCommand(bot, command)));
    return new collection_js_1.Collection(results.map((result) => {
        const command = bot.transformers.applicationCommand(bot, result);
        return [command.id, command];
    }));
}
exports.upsertGlobalApplicationCommands = upsertGlobalApplicationCommands;
