"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteFollowupMessage = void 0;
/**
 * Deletes a follow-up message to an interaction.
 *
 * @param bot - The bot instance to use to make the request.
 * @param token - The interaction token to use, provided in the original interaction.
 * @param messageId - The ID of the message to delete.
 *
 * @remarks
 * Unlike `deleteMessage()`, this endpoint allows the bot user to act without needing to see the channel the message is in.
 *
 * Does not support ephemeral follow-up messages due to these being stateless.
 *
 * Fires a _Message Delete_ event.
 *
 * @see {@link https://discord.com/developers/docs/interactions/receiving-and-responding#delete-followup-message}
 */
async function deleteFollowupMessage(bot, token, messageId) {
    return await bot.rest.runMethod(bot.rest, "DELETE", bot.constants.routes.INTERACTION_ID_TOKEN_MESSAGE_ID(bot.applicationId, token, messageId));
}
exports.deleteFollowupMessage = deleteFollowupMessage;
