"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.editFollowupMessage = void 0;
const shared_js_1 = require("../../../types/shared.js");
/**
 * Edits a follow-up message to an interaction.
 *
 * @param bot - The bot instance to use to make the request.
 * @param token - The interaction token to use, provided in the original interaction.
 * @param messageId - The ID of the message to edit.
 * @param options - The parameters for the edit of the message.
 * @returns An instance of the edited {@link Message}.
 *
 * @remarks
 * Unlike `editMessage()`, this endpoint allows the bot user to act without needing to see the channel the message is in.
 *
 * Does not support ephemeral follow-up messages due to these being stateless.
 *
 * Fires a _Message Update_ event.
 *
 * @see {@link https://discord.com/developers/docs/interactions/receiving-and-responding#edit-followup-message}
 */
async function editFollowupMessage(bot, token, messageId, options) {
    const result = await bot.rest.runMethod(bot.rest, "PATCH", bot.constants.routes.WEBHOOK_MESSAGE(bot.applicationId, token, messageId), {
        messageId,
        ...bot.transformers.reverse.interactionResponse(bot, {
            type: shared_js_1.InteractionResponseTypes.UpdateMessage,
            data: options,
        }).data,
    });
    return bot.transformers.message(bot, result);
}
exports.editFollowupMessage = editFollowupMessage;
