"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.crosspostMessage = exports.publishMessage = void 0;
exports.publishMessage = crosspostMessage;
/**
 * Cross-posts a message posted in an announcement channel to subscribed channels.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the announcement channel.
 * @param messageId - The ID of the message to cross-post.
 * @returns An instance of the cross-posted {@link Message}.
 *
 * @remarks
 * Requires the `SEND_MESSAGES` permission.
 *
 * If not cross-posting own message:
 * - Requires the `MANAGE_MESSAGES` permission.
 *
 * Fires a _Message Create_ event in the guilds the subscribed channels are in.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#crosspost-message}
 */
async function crosspostMessage(bot, channelId, messageId) {
    const result = await bot.rest.runMethod(bot.rest, "POST", bot.constants.routes.CHANNEL_MESSAGE_CROSSPOST(channelId, messageId));
    return bot.transformers.message(bot, result);
}
exports.crosspostMessage = crosspostMessage;
