"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMessage = void 0;
/**
 * Gets a message from a channel by the ID of the message.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel from which to get the message.
 * @param messageId - The ID of the message to get.
 * @returns An instance of {@link Message}.
 *
 * @remarks
 * Requires that the bot user be able to see the contents of the channel in which the message was posted.
 *
 * If getting a message from a guild channel:
 * - Requires the `READ_MESSAGE_HISTORY` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#get-channel-message}
 */
async function getMessage(bot, channelId, messageId) {
    const result = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.CHANNEL_MESSAGE(channelId, messageId));
    return bot.transformers.message(bot, result);
}
exports.getMessage = getMessage;
