"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isGetMessagesLimit = exports.isGetMessagesAround = exports.isGetMessagesBefore = exports.isGetMessagesAfter = exports.getMessages = void 0;
const collection_js_1 = require("../../util/collection.js");
const utils_js_1 = require("../../util/utils.js");
/**
 * Gets multiple messages from a channel.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel from which to get the messages.
 * @param options - The parameters for the fetching of the messages.
 * @returns A collection of {@link Message} objects assorted by message ID.
 *
 * @remarks
 * Requires that the bot user be able to see the contents of the channel in which the messages were posted.
 *
 * If getting a messages from a guild channel:
 * - Requires the `READ_MESSAGE_HISTORY` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#get-channel-messages}
 */
async function getMessages(bot, channelId, options) {
    if (options?.limit && (options.limit < 0 || options.limit > 100)) {
        throw new Error(bot.constants.Errors.INVALID_GET_MESSAGES_LIMIT);
    }
    const results = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.CHANNEL_MESSAGES(channelId, options));
    return new collection_js_1.Collection(results.map((result) => {
        const message = bot.transformers.message(bot, result);
        return [message.id, message];
    }));
}
exports.getMessages = getMessages;
function isGetMessagesAfter(options) {
    return (0, utils_js_1.hasProperty)(options, "after");
}
exports.isGetMessagesAfter = isGetMessagesAfter;
function isGetMessagesBefore(options) {
    return (0, utils_js_1.hasProperty)(options, "before");
}
exports.isGetMessagesBefore = isGetMessagesBefore;
function isGetMessagesAround(options) {
    return (0, utils_js_1.hasProperty)(options, "around");
}
exports.isGetMessagesAround = isGetMessagesAround;
function isGetMessagesLimit(options) {
    return (0, utils_js_1.hasProperty)(options, "limit");
}
exports.isGetMessagesLimit = isGetMessagesLimit;
