"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processReactionString = exports.getReactions = void 0;
const collection_js_1 = require("../../../util/collection.js");
/** Get a list of users that reacted with this emoji. */
/**
 * Gets the list of users that reacted with an emoji to a message.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel the message to get the users for is in.
 * @param messageId - The ID of the message to get the users for.
 * @param reaction - The reaction for which to get the users.
 * @param options - The parameters for the fetching of the users.
 * @returns A collection of {@link User} objects assorted by user ID.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#get-reactions}
 */
async function getReactions(bot, channelId, messageId, reaction, options) {
    reaction = processReactionString(reaction);
    const results = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.CHANNEL_MESSAGE_REACTION(channelId, messageId, reaction, options));
    return new collection_js_1.Collection(results.map((result) => {
        const user = bot.transformers.user(bot, result);
        return [user.id, user];
    }));
}
exports.getReactions = getReactions;
function processReactionString(reaction) {
    if (reaction.startsWith("<:")) {
        return reaction.substring(2, reaction.length - 1);
    }
    if (reaction.startsWith("<a:")) {
        return reaction.substring(3, reaction.length - 1);
    }
    return reaction;
}
exports.processReactionString = processReactionString;
