"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.unpinMessage = void 0;
/**
 * Unpins a pinned message in a channel.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel where the message is pinned.
 * @param messageId - The ID of the message to unpin.
 *
 * @remarks
 * Requires that the bot user be able to see the contents of the channel in which the messages were posted.
 *
 * Requires the `MANAGE_MESSAGES` permission.
 *
 * Fires a _Channel Pins Update_ event.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#unpin-message}
 */
async function unpinMessage(bot, channelId, messageId, reason) {
    return await bot.rest.runMethod(bot.rest, "DELETE", bot.constants.routes.CHANNEL_PIN(channelId, messageId), reason ? { reason } : undefined);
}
exports.unpinMessage = unpinMessage;
