"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGuildTemplates = void 0;
const collection_js_1 = require("../../util/collection.js");
/**
 * Gets the list of templates for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the list of templates for.
 * @returns A collection of {@link Template} objects assorted by template code.
 *
 * @remarks
 * Requires the `MANAGE_GUILD` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild-template#get-guild-templates}
 */
async function getGuildTemplates(bot, guildId) {
    const results = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.GUILD_TEMPLATES(guildId));
    return new collection_js_1.Collection(results.map((result) => {
        const template = bot.transformers.template(bot, result);
        return [template.code, template];
    }));
}
exports.getGuildTemplates = getGuildTemplates;
