"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.editWebhookMessage = void 0;
const shared_js_1 = require("../../types/shared.js");
/**
 * Edits a webhook message.
 *
 * @param bot - The bot instance to use to make the request.
 * @param webhookId - The ID of the webhook to edit the message of.
 * @param token - The webhook token, used to edit the message.
 * @param messageId - The ID of the message to edit.
 * @param options - The parameters for the edit of the message.
 * @returns An instance of the edited {@link Message}.
 *
 * @remarks
 * Fires a _Message Update_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/webhook#edit-webhook-message}
 */
async function editWebhookMessage(bot, webhookId, token, messageId, options) {
    const result = await bot.rest.runMethod(bot.rest, "PATCH", bot.constants.routes.WEBHOOK_MESSAGE(webhookId, token, messageId, options), bot.transformers.reverse.interactionResponse(bot, {
        type: shared_js_1.InteractionResponseTypes.UpdateMessage,
        data: options,
    }).data);
    return bot.transformers.message(bot, result);
}
exports.editWebhookMessage = editWebhookMessage;
