"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWebhooks = void 0;
const collection_js_1 = require("../../util/collection.js");
/**
 * Gets the list of webhooks for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the list of webhooks for.
 * @returns A collection of {@link Webhook} objects assorted by webhook ID.
 *
 * @remarks
 * Requires the `MANAGE_WEBHOOKS` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/webhook#get-guild-webhooks}
 */
async function getWebhooks(bot, guildId) {
    const results = await bot.rest.runMethod(bot.rest, "GET", bot.constants.routes.GUILD_WEBHOOKS(guildId));
    return new collection_js_1.Collection(results.map((result) => {
        const webhook = bot.transformers.webhook(bot, result);
        return [webhook.id, webhook];
    }));
}
exports.getWebhooks = getWebhooks;
