"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.processQueue = void 0;
const dntShim = __importStar(require("../_dnt.shims.js"));
/** Processes the queue by looping over each path separately until the queues are empty. */
function processQueue(rest, id) {
    const queue = rest.pathQueues.get(id);
    if (!queue)
        return;
    while (queue.requests.length) {
        rest.debug(`[REST - processQueue] Running while loop.`);
        // SELECT THE FIRST ITEM FROM THIS QUEUE
        const queuedRequest = queue.requests[0];
        // IF THIS DOESN'T HAVE ANY ITEMS JUST CANCEL, THE CLEANER WILL REMOVE IT.
        if (!queuedRequest)
            break;
        const basicURL = rest.simplifyUrl(queuedRequest.request.url, queuedRequest.request.method);
        // IF THIS URL IS STILL RATE LIMITED, TRY AGAIN
        const urlResetIn = rest.checkRateLimits(rest, basicURL);
        if (urlResetIn) {
            // ONLY ADD TIMEOUT IF ANOTHER QUEUE IS NOT PENDING
            if (!queue.isWaiting) {
                queue.isWaiting = true;
                dntShim.setTimeout(() => {
                    queue.isWaiting = false;
                    rest.debug(`[REST - processQueue] rate limited, running setTimeout.`);
                    rest.processQueue(rest, id);
                }, urlResetIn);
            }
            // BREAK WHILE LOOP
            break;
        }
        // IF A BUCKET EXISTS, CHECK THE BUCKET'S RATE LIMITS
        const bucketResetIn = queuedRequest.payload.bucketId
            ? rest.checkRateLimits(rest, queuedRequest.payload.bucketId)
            : false;
        // THIS BUCKET IS STILL RATE LIMITED, RE-ADD TO QUEUE
        if (bucketResetIn)
            continue;
        // EXECUTE THE REQUEST
        // CUSTOM HANDLER FOR USER TO LOG OR WHATEVER WHENEVER A FETCH IS MADE
        rest.debug(`[REST - Add To Global Queue] ${JSON.stringify(queuedRequest.payload)}`);
        rest.globalQueue.push({
            ...queuedRequest,
            urlToUse: queuedRequest.request.url,
            basicURL,
        });
        rest.processGlobalQueue(rest);
        queue.requests.shift();
    }
    // ONCE QUEUE IS DONE, WE CAN TRY CLEANING UP
    rest.cleanupQueues(rest);
}
exports.processQueue = processQueue;
