import type { Bot } from "../../bot.js";
import { BigString } from "../../types/shared.js";
export declare const swapChannels: typeof editChannelPositions;
/**
 * Edits the positions of a set of channels in a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild in which to edit the positions of the channels.
 * @param channelPositions - A set of objects defining the updated positions of the channels.
 *
 * @remarks
 * Requires the `MANAGE_CHANNELS` permission.
 *
 * Fires a _Channel Update_ gateway event for every channel impacted in this change.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#modify-guild-channel-positions}
 */
export declare function editChannelPositions(bot: Bot, guildId: BigString, channelPositions: ModifyGuildChannelPositions[]): Promise<void>;
/** https://discord.com/developers/docs/resources/guild#modify-guild-channel-positions */
export interface ModifyGuildChannelPositions {
    /** Channel id */
    id: string;
    /** Sorting position of the channel */
    position: number | null;
    /** Syncs the permission overwrites with the new parent, if moving to a new category */
    lockPositions?: boolean | null;
    /** The new parent ID for the channel that is moved */
    parentId?: string | null;
}
