import type { Bot } from "../../../bot.js";
import { Channel } from "../../../transformers/channel.js";
import { Embed } from "../../../transformers/embed.js";
import { AllowedMentions, BigString, FileContent, MessageComponents, WithReason } from "../../../types/mod.js";
/**
 * Creates a new thread in a forum channel, and sends a message within the created thread.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the forum channel to create the thread within.
 * @param options - The parameters for the creation of the thread.
 * @returns An instance of {@link Channel} with a nested {@link Message} object.
 *
 * @remarks
 * Requires the `CREATE_MESSAGES` permission.
 *
 * Fires a _Thread Create_ gateway event.
 * Fires a _Message Create_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#start-thread-in-forum-channel}
 *
 * @experimental
 */
export declare function createForumThread(bot: Bot, channelId: BigString, options: CreateForumPostWithMessage): Promise<Channel>;
export interface CreateForumPostWithMessage extends WithReason {
    /** 1-100 character thread name */
    name: string;
    /** Duration in minutes to automatically archive the thread after recent activity */
    autoArchiveDuration: 60 | 1440 | 4320 | 10080;
    /** Amount of seconds a user has to wait before sending another message (0-21600) */
    rateLimitPerUser?: number | null;
    /** The message contents (up to 2000 characters) */
    content?: string;
    /** Embedded `rich` content (up to 6000 characters) */
    embeds?: Embed[];
    /** Allowed mentions for the message */
    allowedMentions?: AllowedMentions;
    /** The contents of the file being sent */
    file?: FileContent | FileContent[];
    /** The components you would like to have sent in this message */
    components?: MessageComponents;
}
