import type { Bot } from "../../bot.js";
import { BigString } from "../../types/shared.js";
import { Collection } from "../../util/collection.js";
import { InviteMetadata } from "../guilds/invites/mod.js";
/**
 * Gets the list of invites for a channel.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel to get the invites of.
 * @returns A collection of {@link InviteMetadata} objects assorted by invite code.
 *
 * @remarks
 * Requires the `MANAGE_CHANNELS` permission.
 *
 * Only usable for guild channels.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#get-channel-invites}
 */
export declare function getChannelInvites(bot: Bot, channelId: BigString): Promise<Collection<string, InviteMetadata>>;
