import type { Bot } from "../../bot.js";
import { Webhook } from "../../transformers/webhook.js";
import { BigString } from "../../types/shared.js";
import { Collection } from "../../util/collection.js";
/**
 * Gets a list of webhooks for a channel.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel which to get the webhooks of.
 * @returns A collection of {@link Webhook} objects assorted by webhook ID.
 *
 * @remarks
 * Requires the `MANAGE_WEBHOOKS` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/webhook#get-channel-webhooks}
 */
export declare function getChannelWebhooks(bot: Bot, channelId: BigString): Promise<Collection<bigint, Webhook>>;
