import type { Bot } from "../../../bot.js";
import { BigString, WithReason } from "../../../mod.js";
import { StageInstance } from "../../../transformers/stageInstance.js";
/**
 * Creates a stage instance associated with a stage channel.
 *
 * @param bot - The bot instance to use to make the request.
 * @param options - The parameters for the creation of the stage instance.
 * @returns An instance of the created {@link StageInstance}.
 *
 * @remarks
 * Requires the user to be a moderator of the stage channel.
 *
 * Fires a _Stage Instance Create_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/stage-instance#create-stage-instance}
 */
export declare function createStageInstance(bot: Bot, options: CreateStageInstance): Promise<StageInstance>;
export interface CreateStageInstance extends WithReason {
    channelId: BigString;
    topic: string;
    /** Notify @everyone that the stage instance has started. Requires the MENTION_EVERYONE permission. */
    sendStartNotification?: boolean;
}
