import type { Bot } from "../../../bot.js";
import { BigString, Channel, ThreadMember } from "../../../mod.js";
import { Collection } from "../../../util/collection.js";
/**
 * Gets the list of all active threads for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the threads of.
 * @returns An instance of {@link ActiveThreads}.
 *
 * @remarks
 * Returns both public and private threads.
 *
 * Threads are ordered by the `id` property in descending order.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#list-active-guild-threads}
 */
export declare function getActiveThreads(bot: Bot, guildId: BigString): Promise<ActiveThreads>;
export declare type ActiveThreads = {
    threads: Collection<bigint, Channel>;
    members: Collection<bigint, ThreadMember>;
};
