import type { Bot } from "../../../bot.js";
import { BigString } from "../../../types/shared.js";
import { ArchivedThreads, ListArchivedThreads } from "./getPublicArchivedThreads.js";
/**
 * Gets the list of private archived threads the bot is a member of for a channel.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel to get the archived threads for.
 * @param options - The parameters for the fetching of threads.
 * @returns An instance of {@link ArchivedThreads}.
 *
 * @remarks
 * Requires the `READ_MESSAGE_HISTORY` permission.
 *
 * Returns threads of type {@link ChannelTypes.GuildPrivateThread}.
 *
 * Threads are ordered by the `id` property in descending order.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#list-joined-private-archived-threads}
 */
export declare function getPrivateJoinedArchivedThreads(bot: Bot, channelId: BigString, options?: ListArchivedThreads): Promise<ArchivedThreads>;
