import type { Bot } from "../../bot.js";
import { Channel } from "../../transformers/channel.js";
import { Guild } from "../../transformers/guild.js";
import { Role } from "../../transformers/role.js";
import { DefaultMessageNotificationLevels, ExplicitContentFilterLevels, SystemChannelFlags, VerificationLevels } from "../../types/shared.js";
/**
 * Creates a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param options - The parameters for the creation of the guild.
 * @returns An instance of the created {@link Guild}.
 *
 * @remarks
 * ⚠️ This route can only be used by bots in __fewer than 10 guilds__.
 *
 * Fires a _Guild Create_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#create-guild}
 */
export declare function createGuild(bot: Bot, options: CreateGuild): Promise<Guild>;
/** https://discord.com/developers/docs/resources/guild#create-guild */
export interface CreateGuild {
    /** Name of the guild (1-100 characters) */
    name: string;
    /** Base64 128x128 image for the guild icon */
    icon?: string;
    /** Verification level */
    verificationLevel?: VerificationLevels;
    /** Default message notification level */
    defaultMessageNotifications?: DefaultMessageNotificationLevels;
    /** Explicit content filter level */
    explicitContentFilter?: ExplicitContentFilterLevels;
    /** New guild roles (first role is the everyone role) */
    roles?: Role[];
    /** New guild's channels */
    channels?: Partial<Channel>[];
    /** Id for afk channel */
    afkChannelId?: string;
    /** Afk timeout in seconds */
    afkTimeout?: number;
    /** The id of the channel where guild notices such as welcome messages and boost events are posted */
    systemChannelId?: string;
    /** System channel flags */
    systemChannelFlags?: SystemChannelFlags;
}
