import { Bot } from "../../../bot.js";
import { Member, User } from "../../../transformers/member.js";
import { BigString } from "../../../types/shared.js";
import { Collection } from "../../../util/collection.js";
/**
 * Gets the list of subscribers to a scheduled event from a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the subscribers to the scheduled event from.
 * @param eventId - The ID of the scheduled event to get the subscribers of.
 * @param options - The parameters for the fetching of the subscribers.
 * @returns A collection of {@link User} objects assorted by user ID.
 *
 * @remarks
 * Requires the `MANAGE_EVENTS` permission.
 *
 * Users are ordered by their IDs in _ascending_ order.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild-scheduled-event#get-guild-scheduled-event-users}
 */
export declare function getScheduledEventUsers(bot: Bot, guildId: BigString, eventId: BigString, options?: GetScheduledEventUsers & {
    withMember?: false;
}): Promise<Collection<bigint, User>>;
export declare function getScheduledEventUsers(bot: Bot, guildId: BigString, eventId: BigString, options?: GetScheduledEventUsers & {
    withMember: true;
}): Promise<Collection<bigint, {
    user: User;
    member: Member;
}>>;
export interface GetScheduledEventUsers {
    /** number of users to return (up to maximum 100), defaults to 100 */
    limit?: number;
    /** whether to also have member objects provided, defaults to false */
    withMember?: boolean;
    /** consider only users before given user id */
    before?: BigString;
    /** consider only users after given user id. If both before and after are provided, only before is respected. Fetching users in-between before and after is not supported. */
    after?: BigString;
}
