import { Bot } from "../../../bot.js";
import { ScheduledEvent } from "../../../transformers/scheduledEvent.js";
import { BigString } from "../../../types/shared.js";
import { Collection } from "../../../util/collection.js";
/**
 * Gets the list of scheduled events for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the scheduled events from.
 * @param options - The parameters for the fetching of the scheduled events.
 * @returns A collection of {@link ScheduledEvent} objects assorted by event ID.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild-scheduled-event#list-scheduled-events-for-guild}
 */
export declare function getScheduledEvents(bot: Bot, guildId: BigString, options?: GetScheduledEvents): Promise<Collection<bigint, ScheduledEvent>>;
export interface GetScheduledEvents {
    /** include number of users subscribed to each event */
    withUserCount?: boolean;
}
