import type { Bot } from "../../bot.js";
import { BigString } from "../../types/shared.js";
import { Collection } from "../../util/collection.js";
import { Ban } from "./getBan.js";
/**
 * Gets the list of bans for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the list of bans for.
 * @param options - The parameters for the fetching of the list of bans.
 * @returns A collection of {@link Ban} objects assorted by user ID.
 *
 * @remarks
 * Requires the `BAN_MEMBERS` permission.
 *
 * Users are ordered by their IDs in _ascending_ order.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#get-guild-bans}
 */
export declare function getBans(bot: Bot, guildId: BigString, options?: GetBans): Promise<Collection<bigint, Ban>>;
export interface GetBans {
    /** Number of users to return (up to maximum 1000). Default: 1000 */
    limit?: number;
    /** Consider only users before given user id */
    before?: BigString;
    /** Consider only users after given user id */
    after?: BigString;
}
