import type { Bot } from "../../bot.js";
import { BigString } from "../../types/shared.js";
/**
 * Gets the number of members that would be kicked from a guild during pruning.
 *
 * @param bot - The bot instance used to make the request
 * @param guildId - The ID of the guild to get the prune count of.
 * @param options - The parameters for the fetching of the prune count.
 * @returns A number indicating the number of members that would be kicked.
 *
 * @remarks
 * Requires the `KICK_MEMBERS` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#get-guild-prune-count}
 */
export declare function getPruneCount(bot: Bot, guildId: BigString, options?: GetGuildPruneCountQuery): Promise<number>;
/** https://discord.com/developers/docs/resources/guild#get-guild-prune-count */
export interface GetGuildPruneCountQuery {
    /** Number of days to count prune for (1 or more), default: 7 */
    days?: number;
    /** Role(s) to include, default: none */
    includeRoles?: string | string[];
}
