import type { Bot } from "../../../bot.js";
import { BigString, ScheduledEvent, TargetTypes, User } from "../../../mod.js";
export declare type BaseInvite = {
    code: string;
    guildId?: BigString;
    channelId?: BigString;
    inviter?: User;
    targetType?: TargetTypes;
    targetUser?: User;
    targetApplicationId?: BigString;
    approximatePresenceCount?: number;
    approximateMemberCount?: number;
    expiresAt?: number;
    guildScheduledEvent?: ScheduledEvent;
};
export declare type InviteMetadata = BaseInvite & {
    uses: number;
    maxUses: number;
    maxAge: number;
    temporary: boolean;
    createdAt: number;
};
/**
 * Gets an invite to a channel by its invite code.
 *
 * @param bot - The bot instance to use to make the request.
 * @param inviteCode - The invite code of the invite to get.
 * @param options - The parameters for the fetching of the invite.
 * @returns An instance of {@link BaseInvite | Invite}.
 *
 * @see {@link https://discord.com/developers/docs/resources/invite#get-invite}
 */
export declare function getInvite(bot: Bot, inviteCode: string, options?: GetInvite): Promise<BaseInvite>;
/** https://discord.com/developers/docs/resources/invite#get-invite */
export interface GetInvite {
    /** Whether the invite should contain approximate member counts */
    withCounts?: boolean;
    /** Whether the invite should contain the expiration date */
    withExpiration?: boolean;
    /** the guild scheduled event to include with the invite */
    scheduledEventId?: BigString;
}
