import type { Bot } from "../../../bot.js";
import { BigString } from "../../../mod.js";
import { Collection } from "../../../util/collection.js";
import { InviteMetadata } from "./getInvite.js";
/**
 * Gets the list of invites for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the invites from.
 * @returns A collection of {@link InviteMetadata | Invite} objects assorted by invite code.
 *
 * @remarks
 * Requires the `MANAGE_GUILD` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/invite#get-invites}
 */
export declare function getInvites(bot: Bot, guildId: BigString): Promise<Collection<string, InviteMetadata>>;
