import type { Bot } from "../../../bot.js";
import { AtLeastOne, BigString } from "../../../types/shared.js";
/**
 * Connects the bot user to a voice or stage channel.
 *
 * This function sends the _Update Voice State_ gateway command over the gateway behind the scenes.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild the voice channel to leave is in.
 *
 * @remarks
 * Requires the `CONNECT` permission.
 *
 * Fires a _Voice State Update_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/topics/gateway#update-voice-state}
 */
export declare function connectToVoiceChannel(bot: Bot, guildId: BigString, channelId: BigString, options?: AtLeastOne<Omit<UpdateVoiceState, "guildId" | "channelId">>): Promise<void>;
/** https://discord.com/developers/docs/topics/gateway#update-voice-state */
export interface UpdateVoiceState {
    /** id of the guild */
    guildId: string;
    /** id of the voice channel client wants to join (null if disconnecting) */
    channelId: string | null;
    /** Is the client muted */
    selfMute: boolean;
    /** Is the client deafened */
    selfDeaf: boolean;
}
