import type { Bot } from "../../bot.js";
import { BigString } from "../../types/shared.js";
/**
 * Builds a URL to a user's avatar stored in the Discord CDN.
 *
 * @param bot - The bot instance to use to build the URL.
 * @param userId - The ID of the user to get the avatar of.
 * @param discriminator - The user's discriminator. (4-digit tag after the hashtag.)
 * @param options - The parameters for the building of the URL.
 * @returns The link to the resource.
 */
export declare function getAvatarURL(bot: Bot, userId: BigString, discriminator: string, options?: {
    avatar: BigString | undefined;
    size?: ImageSize;
    format?: ImageFormat;
}): string;
/**
 * https://discord.com/developers/docs/reference#image-formatting
 * json is only for stickers
 */
export declare type ImageFormat = "jpg" | "jpeg" | "png" | "webp" | "gif" | "json";
/** https://discord.com/developers/docs/reference#image-formatting */
export declare type ImageSize = 16 | 32 | 64 | 128 | 256 | 512 | 1024 | 2048 | 4096;
