import type { SearchMembers } from "../../types/discordeno.js";
import { Bot } from "../../bot.js";
import { Member } from "../../transformers/member.js";
import { Collection } from "../../util/collection.js";
import { BigString } from "../../types/shared.js";
/**
 * Gets the list of members whose usernames or nicknames start with a provided string.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to search in.
 * @param query - The string to match usernames or nicknames against.
 * @param options - The parameters for searching through the members.
 * @returns A collection of {@link Member} objects assorted by user ID.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#search-guild-members}
 */
export declare function searchMembers(bot: Bot, guildId: BigString, query: string, options?: Omit<SearchMembers, "query">): Promise<Collection<bigint, Member>>;
