import type { Bot } from "../../bot.js";
import { BigString } from "../../types/shared.js";
/**
 * Deletes multiple messages from a channel.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel to delete the messages from.
 * @param messageIds - The IDs of the messages to delete from the channel.
 *
 * @remarks
 * Requires the `MANAGE_MESSAGES` permission.
 *
 * ⚠️ Messages older than 2 weeks old cannot be deleted.
 *
 * Fires a _Message Delete Bulk_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#bulk-delete-messages}
 */
export declare function deleteMessages(bot: Bot, channelId: BigString, messageIds: BigString[], reason?: string): Promise<void>;
