import type { Bot } from "../../bot.js";
import { Message } from "../../transformers/message.js";
import { BigString } from "../../types/shared.js";
import { Collection } from "../../util/collection.js";
/**
 * Gets multiple messages from a channel.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel from which to get the messages.
 * @param options - The parameters for the fetching of the messages.
 * @returns A collection of {@link Message} objects assorted by message ID.
 *
 * @remarks
 * Requires that the bot user be able to see the contents of the channel in which the messages were posted.
 *
 * If getting a messages from a guild channel:
 * - Requires the `READ_MESSAGE_HISTORY` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#get-channel-messages}
 */
export declare function getMessages(bot: Bot, channelId: BigString, options?: GetMessagesOptions): Promise<Collection<bigint, Message>>;
/** https://discord.com/developers/docs/resources/channel#get-channel-messages-query-string-params */
export interface GetMessagesLimit {
    /** Max number of messages to return (1-100) default 50 */
    limit?: number;
}
/** https://discord.com/developers/docs/resources/channel#get-channel-messages-query-string-params */
export interface GetMessagesAround extends GetMessagesLimit {
    /** Get messages around this message id */
    around?: BigString;
}
/** https://discord.com/developers/docs/resources/channel#get-channel-messages-query-string-params */
export interface GetMessagesBefore extends GetMessagesLimit {
    /** Get messages before this message id */
    before?: BigString;
}
/** https://discord.com/developers/docs/resources/channel#get-channel-messages-query-string-params */
export interface GetMessagesAfter extends GetMessagesLimit {
    /** Get messages after this message id */
    after?: BigString;
}
export declare type GetMessagesOptions = GetMessagesAfter | GetMessagesBefore | GetMessagesAround | GetMessagesLimit;
export declare function isGetMessagesAfter(options: GetMessagesOptions): options is GetMessagesAfter;
export declare function isGetMessagesBefore(options: GetMessagesOptions): options is GetMessagesBefore;
export declare function isGetMessagesAround(options: GetMessagesOptions): options is GetMessagesAround;
export declare function isGetMessagesLimit(options: GetMessagesOptions): options is GetMessagesLimit;
