import type { Bot } from "../../../bot.js";
import { BigString } from "../../../types/shared.js";
/**
 * Deletes a reaction added by the bot user from a message.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel the message to delete the reaction from is in.
 * @param messageId - The ID of the message to delete the reaction from.
 * @param reaction - The reaction to delete from the message.
 *
 * @remarks
 * Requires the `READ_MESSAGE_HISTORY` permission.
 *
 * Fires a _Message Reaction Remove_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#delete-own-reaction}
 */
export declare function deleteOwnReaction(bot: Bot, channelId: BigString, messageId: BigString, reaction: string): Promise<void>;
/**
 * Deletes a user's reaction from a message.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel the message to delete the reaction from is in.
 * @param messageId - The ID of the message to delete the reaction from.
 * @param userId - The ID of the user whose reaction to delete.
 * @param reaction - The reaction to delete from the message.
 *
 * @remarks
 * Requires the `READ_MESSAGE_HISTORY` permission.
 *
 * Requires the `MANAGE_MESSAGES` permission.
 *
 * Fires a _Message Reaction Remove_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#delete-user-reaction}
 */
export declare function deleteUserReaction(bot: Bot, channelId: BigString, messageId: BigString, userId: BigString, reaction: string): Promise<void>;
