import type { Bot } from "../../../bot.js";
import { User } from "../../../transformers/member.js";
import { BigString } from "../../../types/shared.js";
import { Collection } from "../../../util/collection.js";
/** Get a list of users that reacted with this emoji. */
/**
 * Gets the list of users that reacted with an emoji to a message.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel the message to get the users for is in.
 * @param messageId - The ID of the message to get the users for.
 * @param reaction - The reaction for which to get the users.
 * @param options - The parameters for the fetching of the users.
 * @returns A collection of {@link User} objects assorted by user ID.
 *
 * @see {@link https://discord.com/developers/docs/resources/channel#get-reactions}
 */
export declare function getReactions(bot: Bot, channelId: BigString, messageId: BigString, reaction: string, options?: GetReactions): Promise<Collection<bigint, User>>;
export declare function processReactionString(reaction: string): string;
/** https://discord.com/developers/docs/resources/channel#get-reactions-query-string-params */
export interface GetReactions {
    /** Get users after this user Id */
    after?: string;
    /** Max number of users to return (1-100) */
    limit?: number;
}
