import { Bot } from "../../bot.js";
import { Role } from "../../transformers/role.js";
import { BigString } from "../../types/shared.js";
import { Collection } from "../../util/collection.js";
/**
 * Edits the positions of a set of roles.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to edit the role positions in.
 * @param options - The parameters for the edit of the role positions.
 * @returns A collection of {@link Role} objects assorted by role ID.
 *
 * @remarks
 * Requires the `MANAGE_ROLES` permission.
 *
 * Fires a _Guild Role Update_ gateway event for every role impacted in this change.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#modify-guild-role-positions}
 */
export declare function modifyRolePositions(bot: Bot, guildId: BigString, options: ModifyRolePositions[]): Promise<Collection<bigint, Role>>;
export interface ModifyRolePositions {
    /** The role id */
    id: BigString;
    /** The sorting position for the role. */
    position?: number | null;
}
