import type { Bot } from "../../bot.js";
import { Role } from "../../transformers/role.js";
import { BigString } from "../../types/shared.js";
import { Collection } from "../../util/collection.js";
/**
 * Gets the list of roles for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the list of roles for.
 * @returns A collection of {@link Role} objects assorted by role ID.
 *
 * @remarks
 * ⚠️ This endpoint should be used sparingly due to {@link User} objects already being included in guild payloads.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild#get-guild-roles}
 */
export declare function getRoles(bot: Bot, guildId: BigString): Promise<Collection<bigint, Role>>;
