import type { Bot } from "../../bot.js";
import { Guild } from "../../transformers/guild.js";
/**
 * Creates a guild from a template.
 *
 * @param bot - The bot instance to use to make the request.
 * @param templateCode - The code of the template.
 * @param options - The parameters for the creation of the guild.
 * @returns An instance of the created {@link Guild}.
 *
 * @remarks
 * ⚠️ This route can only be used by bots in __fewer than 10 guilds__.
 *
 * Fires a _Guild Create_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild-template#create-guild-from-guild-template}
 */
export declare function createGuildFromTemplate(bot: Bot, templateCode: string, options: CreateGuildFromTemplate): Promise<Guild>;
/** https://discord.com/developers/docs/resources/template#create-guild-from-template-json-params */
export interface CreateGuildFromTemplate {
    /** Name of the guild (2-100 characters) */
    name: string;
    /** base64 128x128 image for the guild icon */
    icon?: string;
}
