import type { Bot } from "../../bot.js";
import { Template } from "../../transformers/template.js";
import { BigString } from "../../types/shared.js";
/**
 * Edits a template's settings.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to edit a template of.
 * @param templateCode - The code of the template to edit.
 * @param options - The parameters for the edit of the template.
 * @returns An instance of the edited {@link Template}.
 *
 * @remarks
 * Requires the `MANAGE_GUILD` permission.
 *
 * Fires a _Guild Update_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/guild-template#modify-guild-template}
 */
export declare function editGuildTemplate(bot: Bot, guildId: BigString, templateCode: string, options: ModifyGuildTemplate): Promise<Template>;
/** https://discord.com/developers/docs/resources/template#modify-guild-template */
export interface ModifyGuildTemplate {
    /** Name of the template (1-100 characters) */
    name?: string;
    /** Description of the template (0-120 characters) */
    description?: string | null;
}
