import type { Bot } from "../../bot.js";
import { BigString, WithReason } from "../../mod.js";
import { Webhook } from "../../transformers/webhook.js";
/**
 * Creates a webhook.
 *
 * @param bot - The bot instance to use to make the request.
 * @param channelId - The ID of the channel to create the webhook in.
 * @param options - The parameters for the creation of the webhook.
 * @returns An instance of the created {@link Webhook}.
 *
 * @remarks
 * Requires the `MANAGE_WEBHOOKS` permission.
 *
 * ⚠️ The webhook name must not contain the string 'clyde' (case-insensitive).
 *
 * Fires a _Webhooks Update_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/webhook#create-webhook}
 */
export declare function createWebhook(bot: Bot, channelId: BigString, options: CreateWebhook): Promise<Webhook>;
export interface CreateWebhook extends WithReason {
    /** Name of the webhook (1-80 characters) */
    name: string;
    /** Image url for the default webhook avatar */
    avatar?: string | null;
}
