import type { Bot } from "../../bot.js";
import { BigString, WithReason } from "../../mod.js";
import { Webhook } from "../../transformers/webhook.js";
/**
 * Edits a webhook.
 *
 * @param bot - The bot instance to use to make the request.
 * @param webhookId - The ID of the webhook to edit.
 * @returns An instance of the edited {@link Webhook}.
 *
 * @remarks
 * Requires the `MANAGE_WEBHOOKS` permission.
 *
 * Fires a _Webhooks Update_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/webhook#edit-webhook}
 */
export declare function editWebhook(bot: Bot, webhookId: BigString, options: ModifyWebhook): Promise<Webhook>;
export interface ModifyWebhook extends WithReason {
    /** The default name of the webhook */
    name?: string;
    /** Image for the default webhook avatar */
    avatar?: BigString | null;
    /** The new channel id this webhook should be moved to */
    channelId?: BigString;
}
