import type { Bot } from "../../bot.js";
import { Message } from "../../transformers/message.js";
import { InteractionCallbackData } from "../../types/discordeno.js";
import { BigString } from "../../types/shared.js";
/**
 * Edits a webhook message.
 *
 * @param bot - The bot instance to use to make the request.
 * @param webhookId - The ID of the webhook to edit the message of.
 * @param token - The webhook token, used to edit the message.
 * @param messageId - The ID of the message to edit.
 * @param options - The parameters for the edit of the message.
 * @returns An instance of the edited {@link Message}.
 *
 * @remarks
 * Fires a _Message Update_ gateway event.
 *
 * @see {@link https://discord.com/developers/docs/resources/webhook#edit-webhook-message}
 */
export declare function editWebhookMessage(bot: Bot, webhookId: BigString, token: string, messageId: BigString, options: InteractionCallbackData & {
    threadId?: BigString;
}): Promise<Message>;
