import type { Bot } from "../../bot.js";
import { Webhook } from "../../transformers/webhook.js";
import { BigString } from "../../types/shared.js";
import { Collection } from "../../util/collection.js";
/**
 * Gets the list of webhooks for a guild.
 *
 * @param bot - The bot instance to use to make the request.
 * @param guildId - The ID of the guild to get the list of webhooks for.
 * @returns A collection of {@link Webhook} objects assorted by webhook ID.
 *
 * @remarks
 * Requires the `MANAGE_WEBHOOKS` permission.
 *
 * @see {@link https://discord.com/developers/docs/resources/webhook#get-guild-webhooks}
 */
export declare function getWebhooks(bot: Bot, guildId: BigString): Promise<Collection<bigint, Webhook>>;
